@@ -4,17 +4,19 @@ require 'rbconfig'
 
 require 'mkmf'
 
-if defined?(CFLAGS)
-  if CFLAGS.index(CONFIG['CCDLFLAGS'])
-    $CFLAGS = CFLAGS + ' ' + CONFIG['CCDLFLAGS']
-  else
-    $CFLAGS = CFLAGS
-  end
-else
-  $CFLAGS = CONFIG['CFLAGS']
-end
-$LDFLAGS = CONFIG['LDFLAGS']
-$LIBPATH.push(Config::CONFIG['libdir'])
+#if defined?(CFLAGS)
+#  if CFLAGS.index(CONFIG['CCDLFLAGS'])
+#    $CFLAGS = CFLAGS + ' ' + CONFIG['CCDLFLAGS']
+#  else
+#    $CFLAGS = CFLAGS
+#  end
+#else
+#  $CFLAGS = CONFIG['CFLAGS']
+#end
+#$LDFLAGS = CONFIG['LDFLAGS']
+#$LDFLAGS = "-L/usr/local/lib"
+#$LIBPATH.push(Config::CONFIG['libdir'])
+$LDFLAGS = "-Lc:/mingw/local/lib"
 
 def crash(str)
   printf(" extconf failure: %s\n", str)
@@ -103,6 +105,8 @@ need libxml2.
 EOL
 end
 
+have_func('rb_io_bufwrite', 'ruby/io.h')
+
 # For FreeBSD add /usr/local/include
 $INCFLAGS << " -I/usr/local/include"
 
