@@ -46,7 +46,7 @@ static void rxml_node_deregisterNode(xmlNodePtr xnode)
   if (xnode->_private)
   {
     /* Node was wrapped.  Set the _private member to free and
-      then dislabe the dfree function so that Ruby will not
+      then disable the dfree function so that Ruby will not
       try to free the node a second time. */
     VALUE node = (VALUE) xnode->_private;
     RDATA(node)->data = NULL;
@@ -397,11 +397,12 @@ static VALUE rxml_node_content_get(VALUE self)
 static VALUE rxml_node_content_set(VALUE self, VALUE content)
 {
   xmlNodePtr xnode;
+  xmlChar* encoded_content;
 
   Check_Type(content, T_STRING);
   xnode = rxml_get_xnode(self);
-  // XXX docs indicate need for escaping entites, need to be done? danj
-  xmlNodeSetContent(xnode, (xmlChar*) StringValuePtr(content));
+  encoded_content = xmlEncodeSpecialChars(xnode->doc, (xmlChar*) StringValuePtr(content));
+  xmlNodeSetContent(xnode, encoded_content);
   return (Qtrue);
 }
 
@@ -618,10 +619,17 @@ static VALUE rxml_node_to_s(int argc, VALUE *argv, VALUE self)
   xmlNodeDumpOutput(output, xnode->doc, xnode, level, indent, xencoding);
   xmlOutputBufferFlush(output);
 
+#ifdef LIBXML2_NEW_BUFFER
+  if (output->conv)
+    result = rxml_new_cstr((const char*) xmlBufContent(output->conv), xencoding);
+  else
+    result = rxml_new_cstr((const char*) xmlBufContent(output->buffer), xencoding);
+#else
   if (output->conv)
     result = rxml_new_cstr((const char*) output->conv->content, xencoding);
   else
     result = rxml_new_cstr((const char*) output->buffer->content, xencoding);
+#endif
 
   xmlOutputBufferClose(output);
   
@@ -1136,8 +1144,14 @@ static VALUE rxml_node_remove_ex(VALUE self)
      namespaces, etc.  For a node to live on its own, it
      needs to get its own copies of this information.*/
   xresult = xmlDocCopyNode(xnode, NULL, 1);
-  
-  /* Now free the original node. */
+
+  /* This ruby node object no longer points at the node.*/
+  xnode->_private = NULL;
+  RDATA(self)->data = NULL;
+
+  /* Now free the original node.  This will call the deregister node
+    callback which would reset the mark and free function except for 
+	the fact we set the _private field to null above*/
   xmlFreeNode(xnode);
 
   /* Now wrap the new node */
